/* ver.B.b14.02(BLAZE) */


#include "version.h"


VERSION xl_code_version = {
	"XL.code",
	"XL.lib",
	"(C) 2000-2007 Hirohisa Mori",
	"ver.B.b14.02(BLAZE)",
	2007,2,27,
	0,
	"XL protocol library ",
};

